TODO
====
- Think of a way to change the progress bars functionalities to pexpect instead of subprocess
- Add python 2 support (to most of the functions, I guess)
- Improve the code
- Fix any bugs encountered
